@@ -106,9 +106,7 @@ class ComputeEngineGenerator(GCPGenerator):
         row["labels"] = self.determine_labels(self.LABELS)
         row["system_labels"] = self.determine_system_labels(sku[3])
         if self.resource_level:
-            resource = self._generate_resource(
-                self._resource_name, self._resource_global_name, self.project.get("region")
-            )
+            resource = self._generate_resource(self.project.get("region"))
             row["resource.name"] = resource.get("name")
             row["resource.global_name"] = resource.get("global_name")
 
