@@ -25,6 +25,7 @@ from random import choice
 from random import randint
 from random import uniform
 import calendar
+from nise.util.constants import SECONDS_IN_HOUR
 
 from nise.generators.generator import AbstractGenerator
 
@@ -172,6 +173,13 @@ class GCPGenerator(AbstractGenerator):
         self._currency = self.attributes.get("currency", currency)
         self._sku = None
 
+    @property
+    def project_id(self):
+        if proj_id := self.project.get("project.id"):
+            return proj_id
+        if proj_id := self.project.get("id"):
+            return proj_id
+
     @staticmethod
     def _create_days_list(start_date, end_date):
         """Create a list of days given the date range args."""
@@ -237,7 +245,7 @@ class GCPGenerator(AbstractGenerator):
         if usage_unit == "bytes":
             return self.fake.pyint(min_value=1000, max_value=10000000)
         if usage_unit == "seconds":
-            return self.fake.pyfloat(max_value=3600, positive=True)
+            return self.fake.pyfloat(max_value=SECONDS_IN_HOUR, positive=True)
         return 0
 
     def _gen_pricing_unit_amount(self, pricing_unit, amount):
@@ -251,7 +259,7 @@ class GCPGenerator(AbstractGenerator):
         if pricing_unit == "gibibyte":
             return amount * (9.31323 * 10**-0)
         if pricing_unit == "hour":
-            return amount / 3600.00
+            return amount / SECONDS_IN_HOUR
         return 0
 
     def _gen_cost(self, pricing_amount):
@@ -322,18 +330,15 @@ class GCPGenerator(AbstractGenerator):
         else:
             return json.dumps(label_format)
 
-    def _generate_resource(self, resource_name=None, resource_global_name=None, region=None):
-        name = resource_name
-        global_name = resource_global_name
-        proj_id = self.project.get("project.id")
-        if proj_id is None:
-            proj_id = self.project.get("id")
-        if not name:
+    def _generate_resource(self, region=None):
+        name = self._resource_name
+        global_name = self._resource_global_name
+        if not self._resource_name:
             name = self.fake.word()
-            name = f"projects/{proj_id}/instances/{name}"
-        if not global_name:
+            name = f"projects/{self.project_id}/instances/{name}"
+        if not self._resource_global_name:
             id = "".join([choice(string.digits) for _ in range(19)])
-            global_name = f"//compute.googleapis.com/projects/{proj_id}/zones/{region}/instances/{id}"
+            global_name = f"//compute.googleapis.com/projects/{self.project_id}/zones/{region}/instances/{id}"
         return {"name": name, "global_name": global_name}
 
     def _add_common_usage_info(self, row, start, end, **kwargs):
